@@ -103,8 +103,12 @@ TECH_CLASSES = [
     "Mimas",
     "StingrayOJ",
     "Copperhead",
+    "Copperhead12",
     "Ampere",
     "Python11",
+    "Saipan",
+    "PyramidPlus",
+    "Hbpl1",
 ]
 
 TECH_CLASSES.sort()
@@ -159,7 +163,9 @@ TECH_CLASS_PDLS = {
     "Mimas"      : 'pcl3',
     "StingrayOJ"   : 'pcl3',
     "Copperhead"   : 'pcl3',
-    "Ampere"	   : 'pcl3'
+    "Copperhead12"   : 'pcl3',
+    "Ampere"	   : 'pcl3',
+    "Hbpl1"         : 'hbpl1'
 }
 
 PDL_TYPE_PCL = 0  # less preferred
@@ -183,6 +189,7 @@ PDL_TYPES = { # Used to prioritize PPD file selection in prnt.cups.getPPDFile2()
     'jpg' : PDL_TYPE_HOST,
     'jetready' : PDL_TYPE_HOST,
     'jr' : PDL_TYPE_HOST,
+    'hbpl1' : PDL_TYPE_HOST,
 }
 
 
@@ -306,7 +313,6 @@ class ModelData:
             'power-settings': TYPE_INT,
             'pq-diag-type' : TYPE_INT,
             'r-type' : TYPE_INT,
-            'scan-style' : TYPE_INT,
             'scan-type' : TYPE_INT,
             'scan-src' : TYPE_INT,
             #'scan-duplex' : TYPE_BOOL,
