@@ -142,7 +142,7 @@ def run (command, timeout=-1, withexitstatus=False, events=None, extra_args=None
     Examples:
     Start the apache daemon on the local machine:
         from pexpect import *
-        run ("/usr/sbin/apachectl start")
+        run ("/etc/rc.d/httpd -f start")
     Check in a file using SVN:
         from pexpect import *
         run ("svn ci -m 'automatic commit' my_file.py")
