@@ -20,7 +20,8 @@
 #
 
 # Std Lib
-import sys, struct
+import sys
+import struct
 
 # Local
 from g import *
@@ -129,7 +130,7 @@ def buildPMLSetPacket(oid, value, data_type): # String dotted notation
 
     return p
 
-def ConvertToPMLDataFormat(value, data_type): 
+def ConvertToPMLDataFormat(value, data_type):
     if data_type in (TYPE_ENUMERATION, TYPE_SIGNED_INTEGER, TYPE_COLLECTION):
         data = struct.pack(">i", int(value))
 
@@ -359,6 +360,7 @@ PRINT_INTERNAL_PAGE_COLOR_CAL_VERIFICATION = 1104
 PRINT_INTERNAL_PAGE_ALIGNMENT_PAGE = 1100 # LBOW/OJ Pro L7xxx
 PRINT_INTERNAL_PAGE_ALIGNMENT_PAGE_VERIFICATION = 1150 # LBOW
 PRINT_INTERNAL_PAGE_LINEFEED_CALIBRATION = 1407 # OJ Pro
+PRINT_INTERNAL_PAGE_AUTOMATIC_COLOR_CALIBRATION = 1408 # PS Pro B8800
 PRINT_INTERNAL_PAGE_PRINT_QUALITY_DIAGNOSTIC = 1409 # OJ Pro
 
 # From xojpanel
@@ -510,12 +512,23 @@ POWER_MODE_CHARGING = 0x04
 POWER_MODE_DISCHARGING = 0x08
 POWER_MODE_BATTERY_LEVEL_KNOWN = 0x10
 
+OID_BATTERY_LEVEL_2 = ('1.1.2.61', TYPE_SIGNED_INTEGER)
+
+OID_POWER_SETTINGS = ('1.1.2.118', TYPE_ENUMERATION)
+OID_POWER_SETTINGS_15MIN = 1
+OID_POWER_SETTINGS_30MIN = 2
+OID_POWER_SETTINGS_45MIN = 3
+OID_POWER_SETTINGS_1HR = 4
+OID_POWER_SETTINGS_2HR = 5
+OID_POWER_SETTINGS_3HR = 6
+OID_POWER_SETTINGS_NEVER = 999
+
 #
 # Fax
 #
 
 OID_DEV_DOWNLOAD_TIMEOUT = ('1.1.1.17', TYPE_SIGNED_INTEGER)
-DEFAULT_DOWNLOAD_TIMEOUT = 60
+DEFAULT_DOWNLOAD_TIMEOUT = 600
 
 OID_FAX_DOWNLOAD_ERROR = ('1.3.7.2.6', TYPE_SIGNED_INTEGER)
 
@@ -565,6 +578,44 @@ UPDN_STATE_STR = {UPDN_STATE_IDLE: "Idle",
                   UPDN_STATE_NEWPAGE: "New page",
                   UPDN_STATE_DISABLED: "Disabled",}
 
+# Fax download errors (taken from doc/Fax/WindowsFax/sdcore/DevIO/DevIODefs.h)
+#
+DN_ERROR_NONE = 0
+DN_ERROR_HOST_ABORT = 705
+DN_ERROR_STOP_KEY_PRESSED = 706
+DN_ERROR_SESSION_FAIL = 709
+DN_ERROR_TX_ERROR = 710
+DN_ERROR_PHONE_UNAVAILABLE = 711
+DN_ERROR_OUT_OF_MEMORY = 713
+DN_ERROR_RESULT_BUSY = 714
+DN_ERROR_NO_ANSWER = 715
+DN_ERROR_NO_DIAL_TONE = 716
+DN_ERROR_DOC_JAM = 717
+DN_ERROR_DOOR_OPEN = 718
+DN_ERROR_POWER_FAILED = 719
+DN_ERROR_BLACKLIST = 720
+DN_ERROR_DOC_STORAGE_FULL = 721
+DN_ERROR_RESULT_COLOR_UNSUP = 722
+DN_ERROR_UNKNOWN = 9999
+
+DN_ERROR_STR = {DN_ERROR_NONE: "None",
+                DN_ERROR_HOST_ABORT: "Host aborted",
+                DN_ERROR_STOP_KEY_PRESSED: "Stop key pressed",
+                DN_ERROR_SESSION_FAIL: "Session failed",
+                DN_ERROR_TX_ERROR: "Transmit error",
+                DN_ERROR_PHONE_UNAVAILABLE: "Phone unavailable",
+                DN_ERROR_OUT_OF_MEMORY: "Out of memory",
+                DN_ERROR_RESULT_BUSY: "Result busy",
+                DN_ERROR_NO_ANSWER: "No answer",
+                DN_ERROR_NO_DIAL_TONE: "No dial tone",
+                DN_ERROR_DOC_JAM: "Document jammed",
+                DN_ERROR_DOOR_OPEN: "Door open",
+                DN_ERROR_POWER_FAILED: "Power failed",
+                DN_ERROR_BLACKLIST: "Blacklisted",
+                DN_ERROR_DOC_STORAGE_FULL: "Document storage full",
+                DN_ERROR_RESULT_COLOR_UNSUP: "Color unsupported",
+                DN_ERROR_UNKNOWN: "Unknown error"}
+
 OID_FAX_TOKEN = ('1.1.1.27', TYPE_BINARY)
 
 OID_FAX_TX_ID = ('1.1.6.3.2.3', TYPE_SIGNED_INTEGER)
@@ -663,6 +714,7 @@ COPIER_JOB_SETUP = 5
 
 # AiO Specific Copy
 
+OID_COLOR_COPY_REQUEST = ('1.5.1.8', TYPE_ENUMERATION)
 OID_SCAN_TO_PRINTER = ('1.5.1.5', TYPE_SIGNED_INTEGER)
 SCAN_TO_PRINTER_IDLE         = 1
 SCAN_TO_PRINTER_START        = 2
@@ -713,7 +765,7 @@ COPIER_MEDIA_TYPE_PHOTO_GLOSSY        = 10
 COPIER_MEDIA_TYPE_MATTE_PAPER         = 11
 COPIER_MEDIA_TYPE_EVERYDAY_PHOTO      = 12
 COPIER_MEDIA_TYPE_PHOTO_QUAL_INKJET   = 13
-COPIER_MEDIA_TYPE_PHOTO               = 14 
+COPIER_MEDIA_TYPE_PHOTO               = 14
 COPIER_MEDIA_TYPE_AUTOMATIC           = 15
 COPIER_MEDIA_TYPE_ADVANCED_PHOTO      = 16
 COPIER_MEDIA_TYPE_IRON_ON_MIRRORED    = 17
