@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2007 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2010 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,27 +33,42 @@ import struct
 # Local
 from base.g import *
 from base.codes import *
-from base import device, utils, msg, service, msg
-from base.kirbybase import KirbyBase
+from base.ldif import LDIFParser
+from base import device, utils, vcard
 from prnt import cups
 
-
 try:
     import coverpages
 except ImportError:
     pass
-    
+
+try:
+    import dbus
+except ImportError:
+    log.error("dbus is required for PC send fax.")
+
+import warnings
+# Ignore: .../dbus/connection.py:242: DeprecationWarning: object.__init__() takes no parameters
+# (occurring on Python 2.6/dBus 0.83/Ubuntu 9.04)
+warnings.simplefilter("ignore", DeprecationWarning)
+
+
 # Update queue values (Send thread ==> UI)
 STATUS_IDLE = 0
 STATUS_PROCESSING_FILES = 1
-STATUS_DIALING = 2
-STATUS_CONNECTING = 3
-STATUS_SENDING = 4
-STATUS_COMPLETED = 5
-STATUS_CREATING_COVER_PAGE = 6
-STATUS_ERROR = 7
-STATUS_BUSY = 8
-STATUS_CLEANUP = 9
+STATUS_SENDING_TO_RECIPIENT = 2
+STATUS_DIALING = 3
+STATUS_CONNECTING = 4
+STATUS_SENDING = 5
+STATUS_COMPLETED = 6
+STATUS_CREATING_COVER_PAGE = 7
+STATUS_ERROR = 8
+STATUS_BUSY = 9
+STATUS_CLEANUP = 10
+STATUS_ERROR_IN_CONNECTING = 11
+STATUS_ERROR_IN_TRANSMITTING = 12
+STATUS_ERROR_PROBLEM_IN_FAXLINE = 13
+STATUS_JOB_CANCEL = 14 
 
 # Event queue values (UI ==> Send thread)
 EVENT_FAX_SEND_CANCELED = 1
@@ -115,19 +130,74 @@ EVENT_FAX_SEND_CANCELED = 1
 # #==============================================#
 #
 
+RESOLUTION_STD = 1
+RESOLUTION_FINE = 2
+RESOLUTION_300DPI = 3
+
 FILE_HEADER_SIZE = 28
 PAGE_HEADER_SIZE = 24
-    
+# **************************************************************************** #
+
+##skip_dn = ["uid=foo,ou=People,dc=example,dc=com",
+##    "uid=bar,ou=People,dc=example,dc=com", "dc=example,dc=com"]
+
+class FaxLDIFParser(LDIFParser):
+    def __init__(self, input, db):
+        LDIFParser.__init__(self, input)
+        self.db = db
+
+    def handle(self, dn, entry):
+        if dn:
+            try:
+                firstname = entry['givenName'][0]
+            except KeyError:
+                try:
+                    firstname = entry['givenname'][0]
+                except KeyError:
+                    firstname = ''
+
+            try:
+                lastname = entry['sn'][0]
+            except KeyError:
+                lastname = ''
+
+            try:
+                nickname = entry['cn'][0]
+            except KeyError:
+                nickname = firstname + ' ' + lastname
+
+            try:
+                fax = entry['facsimiletelephonenumber'][0] # fax
+            except KeyError:
+                try:
+                    fax = entry['fax'][0]
+                except KeyError:
+                    fax  = ''
+
+            grps = []
+            try:
+                grps = entry['ou']
+            except KeyError:
+                pass
+
+            grps.append(u'All')
+            groups = [g for g in grps if g]
+
+            if nickname:
+                log.debug("Import: name=%s, fax=%s, group(s)=%s, notes=%s" % ( nickname, fax, ','.join(groups), dn))
+                self.db.set(nickname, title, firstname, lastname, fax, groups, dn)
+
+
 
 # **************************************************************************** #
-class FaxAddressBook2(object): # Pickle based address book
+class FaxAddressBook(object): # Pickle based address book
     def __init__(self):
         self._data = {}
         #
-        # { 'name' : {'name': 'name',
-        #             'firstname' : u'', 
-        #             'lastname': u',
-        #             'title' : u'', 
+        # { 'name' : {'name': u'',
+        #             'firstname' : u'', # NOT USED STARTING IN 2.8.9
+        #             'lastname': u', # NOT USED STARTING IN 2.8.9
+        #             'title' : u'',  # NOT USED STARTING IN 2.8.9
         #             'fax': u'',
         #             'groups' : [u'', u'', ...],
         #             'notes' : u'', } ...
@@ -136,35 +206,18 @@ class FaxAddressBook2(object): # Pickle based address book
         self.load()
 
     def load(self):
-        self._fab = os.path.join(prop.user_dir, "fab.pickle")
-        old_fab = os.path.join(prop.user_dir, "fab.db")
+        self._fab = "/dev/null"
+        if prop.user_dir != None:
+            self._fab = os.path.join(prop.user_dir, "fab.pickle")
+            #old_fab = os.path.join(prop.user_dir, "fab.db")
 
-        # Load the existing pickle if present
-        if os.path.exists(self._fab):
-            pickle_file = open(self._fab, "r")
-            self._data = cPickle.load(pickle_file)
-            pickle_file.close()
-
-        elif os.path.exists(old_fab): # convert old KirbyBase file
-            db = FaxAddressBook()
-            all_entries = db.AllRecordEntries()
-
-            for e in all_entries:
-                try:
-                    self.set(e.name, e.title, e.firstname, e.lastname,
-                             e.fax, e.group_list, e.notes)
-                except UnicodeDecodeError:
-                    self.set(e.name.decode('utf-8'), 
-                             e.title.decode('utf-8'),
-                             e.firstname.decode('utf-8'),
-                             e.lastname.decode('utf-8'),
-                             e.fax.decode('utf-8'),
-                             e.group_list, 
-                             e.notes.decode('utf-8'))
-            self.save()
-
-        else:
-            self.save() # save the empty file to create the file
+            # Load the existing pickle if present
+            if os.path.exists(self._fab):
+               pickle_file = open(self._fab, "r")
+               self._data = cPickle.load(pickle_file)
+               pickle_file.close()
+            else:
+               self.save() # save the empty file to create the file
 
 
     def set(self, name, title, firstname, lastname, fax, groups, notes):
@@ -174,10 +227,10 @@ class FaxAddressBook2(object): # Pickle based address book
             grps = [unicode(s.decode('utf-8')) for s in groups]
 
         self._data[unicode(name)] = {'name' : unicode(name),
-                                    'title': unicode(title), 
-                                    'firstname': unicode(firstname),
-                                    'lastname': unicode(lastname),
-                                    'fax': unicode(fax), 
+                                    'title': unicode(title),  # NOT USED STARTING IN 2.8.9
+                                    'firstname': unicode(firstname), # NOT USED STARTING IN 2.8.9
+                                    'lastname': unicode(lastname), # NOT USED STARTING IN 2.8.9
+                                    'fax': unicode(fax),
                                     'notes': unicode(notes),
                                     'groups': grps}
 
@@ -185,11 +238,32 @@ class FaxAddressBook2(object): # Pickle based address book
 
     insert = set
 
+
+    def set_key_value(self, name, key, value):
+        self._data[unicode(name)][key] = value
+        self.save()
+
+
     def get(self, name):
         return self._data.get(name, None)
 
     select = get
 
+    def rename(self, old_name, new_name):
+        try:
+            self._data[old_name]
+        except KeyError:
+            return
+        else:
+            try:
+                self._data[new_name]
+            except KeyError:
+                self._data[new_name] = self._data[old_name].copy()
+                self._data[new_name]['name'] = new_name
+                del self._data[old_name]
+                self.save()
+
+
     def get_all_groups(self):
         all_groups = []
         for e, v in self._data.items():
@@ -198,12 +272,15 @@ class FaxAddressBook2(object): # Pickle based address book
                     all_groups.append(g)
         return all_groups
 
+
     def get_all_records(self):
         return self._data
 
+
     def get_all_names(self):
         return self._data.keys()
 
+
     def save(self):
         try:
             pickle_file = open(self._fab, "w")
@@ -212,22 +289,28 @@ class FaxAddressBook2(object): # Pickle based address book
         except IOError:
             log.error("I/O error saving fab file.")
 
+
     def clear(self):
         self._data = {}
+        self.save()
+
 
     def delete(self, name):
-        if name in self._data: #self.current
+        if name in self._data:
             del self._data[name]
+            self.save()
             return True
 
         return False
 
+
     def last_modification_time(self):
         try:
             return os.stat(self._fab).st_mtime
         except OSError:
             return 0
 
+
     def update_groups(self, group, members):
         for e, v in self._data.items():
             if v['name'] in members: # membership indicated
@@ -236,11 +319,15 @@ class FaxAddressBook2(object): # Pickle based address book
             else:
                 if group in v['groups']:
                     v['groups'].remove(unicode(group))
+        self.save()
+
 
     def delete_group(self, group):
         for e, v in self._data.items():
             if group in v['groups']:
                 v['groups'].remove(unicode(group))
+        self.save()
+
 
     def group_members(self, group):
         members = []
@@ -250,200 +337,131 @@ class FaxAddressBook2(object): # Pickle based address book
         return members
 
 
-# **************************************************************************** #
+    def add_to_group(self, group, members):
+        group_members = self.group_members(group)
+        new_group_members = []
+        for m in members:
+            if m not in group_members:
+                new_group_members.append(m)
 
-# DEPRECATED: TO BE REMOVED
-class FaxAddressBook(KirbyBase): # KirbyBase based address book
-    def __init__(self):
-        KirbyBase.__init__(self)
-        # Transitional code to handle moving of db file
-        t1 = os.path.expanduser('~/.hplip.fab') # old location #1
-        t2 = os.path.expanduser('~/hpfax/hplip.fab') # old location #2
-        self._fab = os.path.join(prop.user_dir, 'fab.db') # new location
-        log.debug("fab.db: %s" % self._fab)
-
-        if os.path.exists(t1) and not os.path.exists(self._fab):
-            import shutil
-            log.debug("Copying %s to %s..." % (t1, self._fab))
-            shutil.move(t1, self._fab)
-
-        elif os.path.exists(t2) and not os.path.exists(self._fab):
-            import shutil
-            log.debug("Copying %s to %s..." % (t2, self._fab))
-            shutil.move(t2, self._fab)
-
-        if not os.path.exists(self._fab):
-            log.debug("Creating new fax address book: %s" % self._fab)
-            self.create()
-
-    def create(self):
-        return KirbyBase.create(self, self._fab,
-            ['name:str',
-             'title:str',
-             'firstname:str',
-             'lastname:str',
-             'fax:str',
-             'groups:str', # comma sep list of group names
-             'notes:str'])
-
-    def filename(self):
-        return self._fab
-
-    def last_modification_time(self):
-        return os.stat(self._fab).st_mtime
-
-    def close(self):
-        return KirbyBase.close(self)
-
-    def insert(self, values):
-        return KirbyBase.insert(self, self._fab, values)
-
-    def insertBatch(self, batchRecords):
-        return KirbyBase.insertBatch(self, self._fab, batchRecords)
-
-    def update(self, fields, searchData, updates, filter=None, useRegExp=False):
-        return KirbyBase.update(self, self._fab, fields, searchData, updates, filter, useRegExp)
-
-    def delete(self, fields, searchData, useRegExp=False):
-        return KirbyBase.delete(self, self._fab, fields, searchData, useRegExp)
-
-    def select(self, fields, searchData, filter=None, useRegExp=False, sortFields=[],
-        sortDesc=[], returnType='list', rptSettings=[0,False]):
-        return KirbyBase.select(self, self._fab, fields, searchData, filter,
-            useRegExp, sortFields, sortDesc, returnType, rptSettings)
-
-    def pack(self):
-        return KirbyBase.pack(self, self._fab)
-
-    def validate(self):
-        return KirbyBase.validate(self, self._fab)
-
-    def drop(self):
-        return KirbyBase.drop(self, self._fab)
-
-    def getFieldNames(self):
-        return KirbyBase.getFieldNames(self, self._fab)
-
-    def getFieldTypes(self):
-        return KirbyBase.getFieldTypes(self, self._fab)
-
-    def len(self):
-        return KirbyBase.len(self, self._fab)
-
-    def GetEntryByRecno(self, recno):
-        return AddressBookEntry(self.select(['recno'], [recno])[0])
-
-    def AllRecords(self):
-        return self.select(['recno'], ['*'])
-
-    def AllRecordEntries(self):
-        return [AddressBookEntry(rec) for rec in self.select(['recno'], ['*'])]
-
-    def GroupEntries(self, group):
-        return [abe.name for abe in self.AllRecordEntries() if group in abe.group_list]
-
-    def AllGroups(self):
-        temp = {}
-        for abe in self.AllRecordEntries():
-            for g in abe.group_list:
-                temp.setdefault(g)
-
-        return temp.keys()
-
-    def UpdateGroupEntries(self, group_name, member_entries):
-        for entry in self.AllRecordEntries():
-
-            if entry.name in member_entries: # membership indicated
-
-                if not group_name in entry.group_list: # entry already member of group
-                    # add it
-                    entry.group_list.append(group_name)
-                    self.update(['recno'], [entry.recno], [','.join(entry.group_list)], ['groups'])
-            else:
-
-                if group_name in entry.group_list: # remove from entry
-                    entry.group_list.remove(group_name)
-                    self.update(['recno'], [entry.recno], [','.join(entry.group_list)], ['groups'])
-
-    def DeleteGroup(self, group_name):
-        for entry in self.AllRecordEntries():
-            if group_name in entry.group_list:
-                entry.group_list.remove(group_name)
-                self.update(['recno'], [entry.recno], [','.join(entry.group_list)], ['groups'])
+        self.update_groups(group, group_members + new_group_members)
 
 
-# **************************************************************************** #
-# DEPRECATED: TO BE REMOVED
-class AddressBookEntry(object):
-    def __init__(self, rec=None):
-        if rec is not None:
-            rec = [x or '' for x in rec]
-            self.recno, self.name, \
-            self.title, self.firstname, self.lastname, \
-            self.fax, self.groups, self.notes = rec
-            self.group_list = []
+    def remove_from_group(self, group, remove_members):
+        group_members = self.group_members(group)
+        new_group_members = []
+        for m in group_members:
+            if m not in remove_members:
+                new_group_members.append(m)
 
-            if len(self.groups):
-                for g in self.groups.split(','):
-                    self.group_list.append(g.strip())
+        self.update_groups(group, new_group_members)
 
-    def __str__(self):
-        return "Recno=%d, Name=%s, Title=%s, First=%s, Last=%s, Fax=%s, Groups=%s, Notes=%s\n" % \
-            (self.recno, self.name, self.title, self.firstname,
-              self.lastname, self.fax, self.group_list, self.notes)
+
+    def rename_group(self, old_group, new_group):
+        members = self.group_members(old_group)
+        self.update_groups(old_group, [])
+        self.update_groups(new_group, members)
+
+
+    def import_ldif(self, filename):
+        try:
+            data = open(filename, 'r').read()
+            log.debug_block(filename, data)
+            parser = FaxLDIFParser(open(filename, 'r'), self)
+            parser.parse()
+            self.save()
+            return True, ''
+        except ValueError, e:
+            return False, e.message
+
+
+    def import_vcard(self, filename):
+        data = file(filename, 'r').read()
+        log.debug_block(filename, data)
+
+        for card in vcard.VCards(vcard.VFile(vcard.opentextfile(filename))):
+            log.debug(card)
+
+            if card['name']:
+                fax = ''
+                for x in range(1, 9999):
+                    if x == 1:
+                        s = 'phone'
+                    else:
+                        s = 'phone%d' % x
+
+                    try:
+                        card[s]
+                    except KeyError:
+                        break
+                    else:
+                        if 'fax' in card[s]['type']:
+                            fax = card[s]['number']
+                            break
+
+                org = card.get('organisation', '')
+                if org:
+                    org = [org]
+                else:
+                    org = card.get('categories', '').split(';')
+                    if not org:
+                        org = []
+
+                org.append(u'All')
+                groups = [o for o in org if o]
+
+                name = card['name']
+                notes = card.get('notes', u'')
+                log.debug("Import: name=%s, fax=%s group(s)=%s notes=%s" % (name, fax, ','.join(groups), notes))
+                self.set(name, u'', u'', u'', fax, groups, notes)
+
+        return True, ''
 
 
 # **************************************************************************** #
 class FaxDevice(device.Device):
 
     def __init__(self, device_uri=None, printer_name=None,
-                 hpssd_sock=None, callback=None, 
-                 fax_type=FAX_TYPE_NONE):
+                 callback=None,
+                 fax_type=FAX_TYPE_NONE,
+                 disable_dbus=False):
 
         device.Device.__init__(self, device_uri, printer_name,
-                               hpssd_sock, callback)
+                               None, callback, disable_dbus)
 
         self.send_fax_thread = None
         self.upload_log_thread = None
         self.fax_type = fax_type
-        #self.fax_type = self.mq['fax-type']
+
+        if not disable_dbus:
+            session_bus = dbus.SessionBus()
+            self.service = session_bus.get_object('com.hplip.StatusService', "/com/hplip/StatusService")
+        else:
+            self.service = None
+
 
     def setPhoneNum(self, num):
         raise AttributeError
-        #return self.setPML(pml.OID_FAX_LOCAL_PHONE_NUM, str(num))
 
     def getPhoneNum(self):
         raise AttributeError
-        #return utils.printable(str(self.getPML(pml.OID_FAX_LOCAL_PHONE_NUM)[1]))
 
     phone_num = property(getPhoneNum, setPhoneNum)
 
 
     def setStationName(self, name):
         raise AttributeError
-        #return self.setPML(pml.OID_FAX_STATION_NAME, str(name))
 
     def getStationName(self):
         raise AttributeError
-        #return utils.printable(str(self.getPML(pml.OID_FAX_STATION_NAME)[1]))
 
     station_name = property(getStationName, setStationName)
 
     def setDateAndTime(self):
         raise AttributeError
-##        t = time.localtime()
-##        p = struct.pack("BBBBBBB", t[0]-2000, t[1], t[2], t[6]+1, t[3], t[4], t[5])
-##        log.debug(repr(p))
-##        return self.setPML(pml.OID_DATE_AND_TIME, p)
 
     def uploadLog(self):
         raise AttributeError
-##        if not self.isUloadLogActive():
-##            self.upload_log_thread = UploadLogThread(self)
-##            self.upload_log_thread.start()
-##            return True
-##        else:
-##            return False
 
     def isUploadLogActive(self):
         raise AttributeError
@@ -451,8 +469,8 @@ class FaxDevice(device.Device):
     def waitForUploadLogThread(self):
         raise AttributeError
 
-    def sendFaxes(self, phone_num_list, fax_file_list, cover_message='', cover_re='', 
-                  cover_func=None, preserve_formatting=False, printer_name='', 
+    def sendFaxes(self, phone_num_list, fax_file_list, cover_message='', cover_re='',
+                  cover_func=None, preserve_formatting=False, printer_name='',
                   update_queue=None, event_queue=None):
 
         raise AttributeError
@@ -475,38 +493,57 @@ class FaxDevice(device.Device):
 
 # **************************************************************************** #
 
+
 def getFaxDevice(device_uri=None, printer_name=None,
-                 hpssd_sock=None, callback=None, 
-                 fax_type=FAX_TYPE_NONE):
-                 
+                 callback=None,
+                 fax_type=FAX_TYPE_NONE,
+                 disable_dbus=False):
+
     if fax_type == FAX_TYPE_NONE:
         if device_uri is None and printer_name is not None:
             printers = cups.getPrinters()
-    
+
             for p in printers:
                 if p.name.lower() == printer_name.lower():
                     device_uri = p.device_uri
                     break
             else:
                 raise Error(ERROR_DEVICE_NOT_FOUND)
-                
+
         if device_uri is not None:
             mq = device.queryModelByURI(device_uri)
             fax_type = mq['fax-type']
-            
+
     log.debug("fax-type=%d" % fax_type)
-                    
+
     if fax_type in (FAX_TYPE_BLACK_SEND_EARLY_OPEN, FAX_TYPE_BLACK_SEND_LATE_OPEN):
         from pmlfax import PMLFaxDevice
-        return PMLFaxDevice(device_uri, printer_name, hpssd_sock, callback, fax_type)
+        return PMLFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
+
+    elif fax_type == FAX_TYPE_SOAP:
+        from soapfax import SOAPFaxDevice
+        return SOAPFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
+
+    elif fax_type == FAX_TYPE_LEDMSOAP:
+        from ledmsoapfax import LEDMSOAPFaxDevice
+        return LEDMSOAPFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
+
+    elif fax_type == FAX_TYPE_MARVELL:
+        from marvellfax import MarvellFaxDevice
+        return MarvellFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
+
+    elif fax_type == FAX_TYPE_LEDM:
+        from ledmfax import LEDMFaxDevice
+        return LEDMFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
 
     else:
         raise Error(ERROR_DEVICE_DOES_NOT_SUPPORT_OPERATION)
 
-
-
 # **************************************************************************** #
 
+
+
+
 # TODO: Define these in only 1 place!
 STATE_DONE = 0
 STATE_ABORTED = 10
@@ -522,15 +559,17 @@ STATE_MERGE_FILES = 90
 STATE_SINGLE_FILE = 100
 STATE_SEND_FAX = 110
 STATE_CLEANUP = 120
-STATE_ERROR = 130 
-    
+STATE_ERROR = 130
+
 class FaxSendThread(threading.Thread):
-    def __init__(self, dev, phone_num_list, fax_file_list, 
+    def __init__(self, dev, service, phone_num_list, fax_file_list,
                  cover_message='', cover_re='', cover_func=None, preserve_formatting=False,
                  printer_name='', update_queue=None, event_queue=None):
 
         threading.Thread.__init__(self)
+
         self.dev = dev # device.Device
+        self.service = service # dbus proxy to status server object
         self.phone_num_list = phone_num_list
         self.fax_file_list = fax_file_list
         self.update_queue = update_queue
@@ -539,7 +578,7 @@ class FaxSendThread(threading.Thread):
         self.cover_re = cover_re
         self.cover_func = cover_func
         self.current_printer = printer_name
-        self.stream = StringIO()  
+        self.stream = StringIO()
         self.prev_update = ''
         self.remove_temp_file = False
         self.preserve_formatting = preserve_formatting
@@ -574,13 +613,13 @@ class FaxSendThread(threading.Thread):
                 self.rendered_file_list.append((fax_file_name, "application/hplip-fax",
                     "HP Fax", fax_file_title))
 
-                log.debug("Processing pre-rendered file: %s (%d pages)" % 
+                log.debug("Processing pre-rendered file: %s (%d pages)" %
                     (fax_file_name, fax_file_pages))
 
             if self.check_for_cancel():
                 state = STATE_ABORTED
 
-        log.debug(self.rendered_file_list)  
+        log.debug(self.rendered_file_list)
 
         if self.check_for_cancel():
             state = STATE_ABORTED
@@ -635,7 +674,7 @@ class FaxSendThread(threading.Thread):
 
 
                 log.debug("Magic=%s Ver=%d Pages=%d hDPI=%d vDPI=%d Size=%d Res=%d Enc=%d" %
-                          (magic, version, total_pages, hort_dpi, 
+                          (magic, version, total_pages, hort_dpi,
                            vert_dpi, page_size, resolution, encoding))
 
                 self.job_total_pages += total_pages
@@ -660,6 +699,17 @@ class FaxSendThread(threading.Thread):
 
         return state
 
+    def decode_fax_header(self, header):
+        try:
+            return struct.unpack(">8sBIHHBBBII", header)
+        except struct.error:
+            return -1, -1, -1, -1, -1, -1, -1, -1, -1, -1
+
+    def decode_page_header(self, header):
+        try:
+            return struct.unpack(">IIIIII", header)
+        except struct.error:
+            return -1, -1, -1, -1, -1, -1
 
     def cover_page(self,  recipient):
         if self.job_total_pages > 1:
@@ -676,7 +726,7 @@ class FaxSendThread(threading.Thread):
             elif not fax_file:
                 state = STATE_ERROR # timeout
             else:
-                self.recipient_file_list.insert(0, (fax_file, "application/hplip-fax", 
+                self.recipient_file_list.insert(0, (fax_file, "application/hplip-fax",
                                                     "HP Fax", 'Cover Page'))
 
                 log.debug("Cover page G3 file: %s" % fax_file)
@@ -689,7 +739,6 @@ class FaxSendThread(threading.Thread):
         state = STATE_SEND_FAX
 
         log.debug("Processing single file...")
-
         self.f = self.recipient_file_list[0][0]
 
         try:
@@ -711,7 +760,7 @@ class FaxSendThread(threading.Thread):
                 state = STATE_ERROR
 
             log.debug("Magic=%s Ver=%d Pages=%d hDPI=%d vDPI=%d Size=%d Res=%d Enc=%d" %
-                      (magic, version, total_pages, hort_dpi, vert_dpi, 
+                      (magic, version, total_pages, hort_dpi, vert_dpi,
                        page_size, resolution, encoding))
 
             f_fd.close()
@@ -729,9 +778,9 @@ class FaxSendThread(threading.Thread):
             f_fd, self.f = utils.make_temp_file()
             log.debug("Temp file=%s" % self.f)
 
-            data = struct.pack(">8sBIHHBBBII", "hplip_g3", 1L, self.job_total_pages,  
-                self.job_hort_dpi, self.job_vert_dpi, self.job_page_size, 
-                self.job_resolution, self.job_encoding, 
+            data = struct.pack(">8sBIHHBBBII", "hplip_g3", 1L, self.job_total_pages,
+                self.job_hort_dpi, self.job_vert_dpi, self.job_page_size,
+                self.job_resolution, self.job_encoding,
                 0L, 0L)
 
             os.write(f_fd, data)
@@ -774,7 +823,7 @@ class FaxSendThread(threading.Thread):
                         self.write_queue((STATUS_PROCESSING_FILES, job_page_num, ''))
 
                         log.debug("Page=%d PPR=%d RPP=%d BPP=%d Thumb=%s" %
-                                  (page_num, ppr, rpp, bytes_to_read, thumbnail_bytes))                    
+                                  (page_num, ppr, rpp, bytes_to_read, thumbnail_bytes))
 
                         os.write(f_fd, fax_file_fd.read(bytes_to_read))
                         job_page_num += 1
@@ -799,9 +848,13 @@ class FaxSendThread(threading.Thread):
         for a in self.phone_num_list:
             yield a
 
+    def next_file_gen(self):
+        for a in self.recipient_file_list:
+            yield a
+
 
     def render_file(self, path, title, mime_type, force_single_page=False):
-        all_pages = True 
+        all_pages = True
         page_range = ''
         page_set = 0
         nup = 1
@@ -812,6 +865,7 @@ class FaxSendThread(threading.Thread):
                          "application/x-perl",
                          "application/x-python",
                          "application/x-shell",
+                         "application/x-sh",
                          "text/plain",]:
 
             cups.addOption('prettyprint')
@@ -825,7 +879,7 @@ class FaxSendThread(threading.Thread):
         sent_job_id = cups.printFile(self.current_printer, path, title)
         cups.resetOptions()
 
-        log.debug("Job ID=%d" % sent_job_id)    
+        log.debug("Job ID=%d" % sent_job_id)
         job_id = 0
 
         time.sleep(1)
@@ -833,29 +887,21 @@ class FaxSendThread(threading.Thread):
         fax_file = ''
         complete = False
 
-        try:
-            sock = service.startup()
-        except Error:
-            return '', True   
-
-        end_time = time.time() + 120.0 
+        end_time = time.time() + 300.0 # wait for 5 min. max
         while time.time() < end_time:
             log.debug("Waiting for fax...")
-            fields, data, result_code = \
-                msg.xmitMessage(sock, "FaxCheck", None,
-                                     {"username": prop.username,
-                                     })
 
-            if result_code == ERROR_FAX_PROCESSING:
-                log.debug("Fax is being rendered...")
+            result = list(self.service.CheckForWaitingFax(self.dev.device_uri, prop.username, sent_job_id))
 
-            elif result_code == ERROR_FAX_READY:
+            fax_file = str(result[7])
+            log.debug("Fax file=%s" % fax_file)
+
+            if fax_file:
                 break
 
             if self.check_for_cancel():
                 log.error("Render canceled. Canceling job #%d..." % sent_job_id)
                 cups.cancelJob(sent_job_id)
-                sock.close()
                 return '', True
 
             time.sleep(1)
@@ -865,34 +911,6 @@ class FaxSendThread(threading.Thread):
             cups.cancelJob(sent_job_id)
             return '', False
 
-        fd, fax_file = utils.make_temp_file()
-
-        while True:
-            log.debug("Transfering fax data...")
-            fields, data, result_code = \
-                msg.xmitMessage(sock, "FaxGetData", None,
-                                     {"username": prop.username,
-                                      "job-id": sent_job_id,
-                                     })
-
-            if data and result_code == ERROR_SUCCESS:
-                os.write(fd, data)
-
-            else:
-                complete = True
-                break
-
-            if self.check_for_cancel():
-                log.error("Render canceled. Canceling job #%d..." % sent_job_id)
-                cups.cancelJob(sent_job_id)
-                os.close(fd)
-                sock.close()
-                return '', True
-
-
-        os.close(fd)
-        sock.close()
-
         return fax_file, False
 
 
@@ -913,24 +931,24 @@ class FaxSendThread(threading.Thread):
         log.debug("Creating cover page...")
 
         pdf = self.cover_func(page_size=coverpages.PAGE_SIZE_LETTER,
-                              total_pages=self.job_total_pages, 
+                              total_pages=self.job_total_pages,
 
-                              recipient_name=a['name'], 
+                              recipient_name=a['name'],
                               recipient_phone='', # ???
-                              recipient_fax=a['fax'], 
+                              recipient_fax=a['fax'],
 
-                              sender_name=self.sender_name, 
-                              sender_phone=user_cfg.fax.voice_phone, 
+                              sender_name=self.sender_name,
+                              sender_phone=user_conf.get('fax', 'voice_phone'),
                               sender_fax=self.sender_fax,
-                              sender_email=user_cfg.fax.email_address, 
+                              sender_email=user_conf.get('fax', 'email_address'),
 
-                              regarding=self.cover_re, 
+                              regarding=self.cover_re,
                               message=self.cover_message,
                               preserve_formatting=self.preserve_formatting)
 
         log.debug("PDF File=%s" % pdf)
-        fax_file, canceled = self.render_file(pdf, 'Cover Page', "application/pdf", 
-            force_single_page=True) 
+        fax_file, canceled = self.render_file(pdf, 'Cover Page', "application/pdf",
+            force_single_page=True)
 
         try:
             os.remove(pdf)
@@ -946,3 +964,9 @@ class FaxSendThread(threading.Thread):
             time.sleep(0)
             self.prev_update = message
 
+
+    def run(self):
+        pass
+
+
+
