@@ -273,13 +273,13 @@ else: # INTERACTIVE_MODE
         log.info("")
 
         from installer import core_install
-        core = core_install.CoreInstall()
+        core = core_install.CoreInstall(core_install.MODE_CHECK)
 
         core.set_plugin_version()
 
         tui.header("PLUG-IN INSTALLATION FOR HPLIP %s" % version)
 
-        if core.check_for_plugin() and plugin_path is None:
+        if core.check_for_plugin() == PLUGIN_INSTALLED and plugin_path is None:
             log.info("The driver plugin for HPLIP %s appears to already be installed." % version)
 
             cont, ans = tui.enter_yes_no("Do you wish to download and re-install the plug-in?")
